/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

											ANALYSIS OF BEHAVIORAL RISK PREFERENCES AND SOEP-IS DESCRIPTIVES
*****************************************************************************************************************************************

This code compares behavioral risk preference between depressed and mentally well. It requires the SOEP-IS data in its original form.
***/

capture ssc install estout  //can delete if already installed

global path ...\soep-is.2016.2_stata_en  //path where SOEP-IS data is stored

use ${path}\irisk.dta, clear

*Give variables preferred names
rename (outcome1_a outcome2_a probab1_a probab2_a outcome1_b outcome2_b ///
probab1_b probab2_b outcome1_c outcome2_c probab1_c probab2_c outcome1_d ///
outcome2_d probab1_d probab2_d) (outcome_a1 outcome_b1 probab_a1 ///
probab_b1 outcome_a2 outcome_b2 probab_a2 probab_b2 outcome_a3 outcome_b3 ///
probab_a3 probab_b3 outcome_a4 outcome_b4 probab_a4 probab_b4)

keep if task==1

//========================
//Here we have a wide file
//========================

g id2 = _n

bysort pid: g count = _n
egen max_c = max(count), by(pid)
drop if max_c > 4 //this gets rid of people who did the task more than once (which we understand through correspondence was a mistake)

merge m:1 pid using ${path}\ppfad.dta, keep(match master) nogen
g age = 2014-gebjahr
g age2 = age^2
g male = sex==1
replace germborn = 0 if germborn!=1

*Other controls
merge m:1 pid syear using ${path}\pgen.dta, keep(match master) nogen
g edu_high=0
replace edu_high=1 if pgsbil>=3&pgsbil<=4 // includes Fachhochschule, Abitur
label var edu_high "Has high education"
*Parent's education
merge m:1 pid using ${path}\bioparen.dta, keepusing(msbil vsbil) keep (match master) nogen
gen fsedu_dummy=.
replace fsedu_dummy=1 if vsbil>=3 & vsbil<=4 // includes Fachhochschule, Abitur
replace fsedu_dummy=0 if vsbil==1 | vsbil==2 | vsbil==5 | vsbil==6
gen msedu_dummy=.
replace msedu_dummy=1 if msbil>=3 & msbil<=4
replace msedu_dummy=0 if msbil==1 | msbil==2 | msbil==5 | msbil==6
gen paredu=0
replace paredu=1 if fsedu_dummy==1 | msedu_dummy==1 // takes highest education of both parents
label variable paredu "father or mother with high education"
drop fsedu_dummy msedu_dummy

*HH controls
merge m:1 hid syear using ${path}\hgen.dta, keep(match master) nogen
replace hghinc = . if hghinc<0
rename hghinc hh_inc //from hgen
label var hh_inc "Monthly Household Net Income (EUR) (CPI adjusted)"
g hh_inc2 = hh_inc^2
label var hh_inc2 "hh_inc squared"
g lhh_inc = log(hh_inc)
label var lhh_inc "log hh_inc" 

qui tab hgtyp1hh, g(hh_type) //household type
label var hh_type1 "Single person household"
label var hh_type2 "Couple without children"
label var hh_type3 "Single parent"
label var hh_type4 "Couple with children <16"
label var hh_type5 "Couple with children >16"
label var hh_type6 "Couple with children <16 & >16"
label var hh_type7 "Multi-generation household"
label var hh_type8 "Other combination household"

*Merge in survey data
merge m:1 pid syear using ${path}\p.dta, keep(match master) nogen

g depressed = ple0019 ==1

*Create the MCS score variable in SOEP-IS (slightly different to main SOEP sample due to one less item)
rename ple0008 status
rename ple0004 stairs
rename ple0027 var1
rename ple0028 var2
rename ple0029 var3
rename ple0030 var4
rename ple0031 var5
rename ple0032 var6
rename ple0033 var7
rename ple0034 var8
rename ple0035 var9

foreach x of varlist status stairs var1-var9 {
replace `x'=. if `x'<0
}

gen pf100 = ((((stairs)/1)-1)/2)*100
gen rp100 = ((((var5+var6)/2)-1)/4)*100
gen re100 = ((((var7+var8)/2)-1)/4)*100
gen mh100 = ((((var1+(6 - var2))/2)-1)/4)*100
gen bp100 = (((var4)-1)/4)*100
gen gh100 = (((6 - status)-1)/4)*100
gen vt100 = (((6 - var3)-1)/4)*100
gen sf100 = (((var9)-1)/4)*100

gen pf_z = (pf100-73.14)/32.15
gen rp_z = (rp100-74.29)/26.46
gen bp_z = (bp100-73.27)/27.14
gen gh_z = (gh100-60.57)/24.08
gen vt_z = (vt100-52.94)/22.84
gen sf_z = (sf100-83.22)/23.57
gen re_z = (re100-81.94)/22.35
gen mh_z = (mh100-61.96)/20.47

gen pf_nbs = (pf_z*10)+50
gen rp_nbs = (rp_z*10)+50
gen bp_nbs = (bp_z*10)+50
gen gh_nbs = (gh_z*10)+50
gen vt_nbs = (vt_z*10)+50
gen sf_nbs = (sf_z*10)+50
gen re_nbs = (re_z*10)+50
gen mh_nbs = (mh_z*10)+50

gen	mcs = (((-0.209*pf_z) + (-0.021*rp_z) + (-0.105*bp_z) + (-0.103*gh_z) + (0.258*vt_z) + (0.333*sf_z) + (0.378*re_z) + (0.489*mh_z))*10)+50

gen mcs_dummy=.
replace mcs_dummy=1 if mcs<=45.6 & mcs!=.
replace mcs_dummy=0 if mcs>45.6 & mcs!=.
label var mcs_dummy "MCS <=45.6"

gen mcs_dummy2=.
replace mcs_dummy2=1 if mcs<=36.54 & mcs!=.  //used for sensitivty analysis
replace mcs_dummy2=0 if mcs>36.54 & mcs!=.
label var mcs_dummy2 "MCS <=36.54"

*Irrationals
g irrational = gamble==4&ch_option==4 //these are people who choose outcome(4,0) with prob(.7,.3) even though they could
//choose outcome(4,0) with prob(0.8,0.2).
egen irrational2 = sum(irrational), by(pid)

preserve 
use ${path}\p.dta, clear
tempfile temp
keep if syear ==2013
keep pid plh0183 plh0254 plh0253 
save "`temp'", replace
restore

drop plh0183 plh0254 plh0253
merge m:1 pid using "`temp'", keep(match master) nogen

//============
//Descriptives
//============

preserve
keep if gamble ==1
local controls male age lhh_inc edu_high paredu germborn hh_type1 hh_type2 hh_type3 hh_type4 hh_type5 hh_type6 hh_type7 hh_type8 

local vars `controls' 
local rows = wordcount("`vars'")

matrix output = J(`rows',6,0) 

foreach var in `vars' {
	forvalues j = 1/`rows' {
		if word("`vars'", `j') == "`var'" local i = `j'
	}
	qui reg `var' mcs_dummy
	mat diff_table=r(table)
	matrix output[`i',1] = _b[_cons] 
	matrix output[`i',3] = _b[_cons]+_b[mcs_dummy]
	matrix output[`i',5] = _b[mcs_dummy]
	matrix output[`i',6] = diff_table[4,1]
	qui count if mcs_dummy==0&e(sample)
	matrix output[`i',2] = r(N) 
	qui count if mcs_dummy==1&e(sample)
	matrix output[`i',4] = r(N)
}

mat colnames output= mean_mcs0 n1 mean_mcs1 n2 diff pval
mat rownames output= `vars' 
mat list output, f(%9.3f)

putexcel set descriptive_stats_SOEP-IS, replace
putexcel A1 = matrix(output), names
restore

//=====================================
//Non-parametric analysis of irisk data
//=====================================

local controls male age age2 lhh_inc edu_high paredu germborn hh_type1-hh_type7 

*Non-parametric regressions
eststo: logit riskier mcs_dummy, or cl(pid) //riskier =1 if they didn't choose sure thing option
eststo: logit riskier mcs_dummy `controls', or cl(pid)
eststo: logit riskier mcs_dummy `controls' if irrational2==0, or cl(pid)
esttab using irisk_nonpara, b(3) se(3) replace star(* 0.10 ** 0.05 *** 0.01) nogap eform csv
eststo clear

*Non-parametric tests for distributions
ranksum ch_option if gamble==1, by(mcs_dummy)
ranksum ch_option if gamble==2, by(mcs_dummy)
ranksum ch_option if gamble==3, by(mcs_dummy)
ranksum ch_option if gamble==4, by(mcs_dummy)

*Graphs
g ch_option_new = 1 if gamble==1&ch_option==2
replace ch_option_new = 2 if gamble==1&ch_option==1

replace ch_option_new = 1 if gamble==2&ch_option==2
replace ch_option_new = 2 if gamble==2&ch_option==1

replace ch_option_new = 1 if gamble==3&ch_option==3
replace ch_option_new = 2 if gamble==3&ch_option==4
replace ch_option_new = 3 if gamble==3&ch_option==2
replace ch_option_new = 4 if gamble==3&ch_option==1

replace ch_option_new = 1 if gamble==4&ch_option==3
replace ch_option_new = 2 if gamble==4&ch_option==2
replace ch_option_new = 3 if gamble==4&ch_option==4
replace ch_option_new = 4 if gamble==4&ch_option==1

forvalues x=1/4{
	if `x'==1 {
		local vals 1 "3€,100%" 2 "32€,10%"
	}
	else if `x'==2 {
		local vals 1 "3€,100%" 2 "4€,80%"
	}
	else if `x'==3 {
		local vals 1 "3€,100%" 2 "4€,70%" 3 "32€,10%" 4 "68€,5%"
	}
	else {
		local vals 1 "3€,100%" 2 "4€,80%" 3 "4€,70%" 4 "34€,10%"
	}
	twoway (histogram ch_option_new if gamble==`x'&mcs_dummy==0, discrete fcolor(gs12) lcolor(white) xlabel(`vals')) ///
	|| (histogram ch_option_new if gamble==`x'&mcs_dummy==1, fcolor(none) lcolor(black) discrete xlabel(`vals')), ///
	scheme(s1manual) legend(order(1 "Mentally well" 2 "Depressed")) xtitle("") ytitle("") title(Scenario `x') name(g`x', replace) nodraw
}
set scheme s1manual
grc1leg g1 g2 g3 g4, legendfrom(g1)
graph export "irisk_graph.pdf", replace

*Non-parametric regressions for alternate MCS threshold
eststo: logit riskier mcs_dummy2, or cl(pid) //riskier =1 if they didn't choose sure thing option
eststo: logit riskier mcs_dummy2 `controls', or cl(pid)
eststo: logit riskier mcs_dummy2 `controls' if irrational2==0, or cl(pid)
esttab using irisk_nonpara_altMCS, b(3) se(3) replace star(* 0.10 ** 0.05 *** 0.01) nogap eform csv
eststo clear

//====================================================
//Make into long file for maximum liklihood estimation
//====================================================

g _mi_miss = 0
mi unset

reshape long outcome_a outcome_b probab_a probab_b, i(id2) j(option)

drop if outcome_a ==-2

g choice = option == ch_option

*Parametric MLE probability weighting version

capture program drop myclogit_plf
program define myclogit_plf
args lnf xb pw

tempvar num den p pw_a

qui gen double `pw_a' = probab_a^`pw'/((probab_a^`pw'+(1-probab_a)^`pw')^(1/`pw'))
qui gen double `num' = exp(`pw_a'*(outcome_a^(1-`xb'))/(1-`xb'))
qui egen double `den' = sum(exp(`pw_a'*(outcome_a^(1-`xb'))/(1-`xb'))), by(id2)
qui gen double `p' = `num'/`den'
qui replace `lnf' = ln(`p')*choice 
end

ml model lf myclogit_plf (r: choice = mcs_dummy) (pw: mcs_dummy), vce(cluster pid)
ml maximize
est store est1

local controls male age age2 lhh_inc edu_high paredu germborn hh_type1-hh_type7 

ml model lf myclogit_plf (r: choice = mcs_dummy `controls') (pw: mcs_dummy), vce(cluster pid)
ml maximize
est store est2

ml model lf myclogit_plf (r: choice = mcs_dummy `controls') (pw: mcs_dummy) if irrational2==0, vce(cluster pid)
ml maximize
est store est3

esttab est1 est2 est3 using irisk_para, b(3) se(3) replace star(* 0.10 ** 0.05 *** 0.01) nogap csv
eststo clear

*Use alternate MCS threshold

ml model lf myclogit_plf (r: choice = mcs_dummy2) (pw: mcs_dummy2), vce(cluster pid)
ml maximize
est store est4

ml model lf myclogit_plf (r: choice = mcs_dummy2 `controls') (pw: mcs_dummy2), vce(cluster pid)
ml maximize
est store est5

ml model lf myclogit_plf (r: choice = mcs_dummy2 `controls') (pw: mcs_dummy2) if irrational2==0, vce(cluster pid)
ml maximize
est store est6

esttab est4 est5 est6 using irisk_para_altMCS, b(3) se(3) replace star(* 0.10 ** 0.05 *** 0.01) nogap csv
eststo clear

