/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

											DATA FILE
*****************************************************************************************************************************************

This code generates the data file for the paper. It requires the SOEP data in its original form (delivered in both Core and Long format).
The final output is a file long in pid and syear (Person * Survey year observations).
***/

***PLEASE ADJUST PATHS***
global soeplong ...SOEP-LONG_v33.1i_stata_bilingual\	//Path where SOEP data is stored in long format
global soep ...\SOEP-CORE_v33.1i_stata_bilingual\		//Path where SOEP data is stored in its core format (separate yearly files, etc.)
global project ...\										//Path where project data should be saved


***********************************************************************************************
* Merge Datasets
***********************************************************************************************

use pid hid syear sex germborn using "${soeplong}ppfadl.dta", clear												
rename pid persnr
merge 1:1 persnr syear using "${soep}health.dta", nogen keepusing(mcs pcs)
merge m:1 persnr using "${soep}bioparen.dta", nogen keepusing(msedu fsedu)
merge m:1 persnr syear using "${soep}cognit.dta", nogen keepusing(f96t90g f99z90r f25r)
rename persnr pid
merge 1:1 pid syear using "${soeplong}pl.dta", nogen keepusing(hid ple0127 plh0204 plh0197 plh0198 plh0199 plh0200 plh0201 plh0202 ///
ple0081 ple0095 plh0192 plh0253 plh0254 plh0244 plh0183 plh0188 pld0043 pld0044 plh0245-plh0252 plh0128 plh0005 plh0212-plh0226 plh0182)
merge 1:1 pid syear using "${soeplong}pequiv.dta", nogen keepusing(d11101 y11101 m11104)
merge 1:1 pid syear using "${soeplong}pgen.dta", nogen keepusing(pgpsbil)
merge m:1 hid syear using "${soeplong}hl.dta", nogen keepusing(hlc0108)
merge m:1 hid syear using "${soeplong}hgen.dta", nogen keepusing(hgtyp1hh hghinc)

***********************************************************************************************
* Generate Variables
***********************************************************************************************

foreach x of varlist hlc0108 {
	replace `x' = 0 if `x' ==-2
}
foreach x of varlist * {
	replace `x'=. if `x'<0
}
************************
*Mental health variable*
************************
gen mcs_dummy=.
replace mcs_dummy=1 if mcs<=45.6 & mcs!=.
replace mcs_dummy=0 if mcs>45.6 & mcs!=.
label var mcs_dummy "MCS <=45.6"

keep if syear>2001
xtset pid syear

******************
*Risk preferences*
******************
rename plh0204 r_gen
rename plh0197 r_drive
rename plh0198 r_fin 
rename plh0199 r_sport
rename plh0200 r_occup 
rename plh0201 r_health 
rename plh0202 r_trust 

*************
*Risk-taking*
*************
* Financial risk
rename hlc0108 risky_assets
rename ple0127 supp_h_ins 
replace supp_h_ins = 0 if supp_h_ins ==2

* Health-related risk behavior
rename ple0095 healthy_diet 
replace healthy_diet = (healthy_diet-5)*-1
label define agree2 1 "[1] Not at all" 2 "[2] A little" 3 "[3] Strong" 4 "[4] Very strong"
label values healthy_diet agree2
rename ple0081 smoke_curr 
replace smoke_curr = 0 if smoke_curr ==2
g exer_weekly = m11104 ==4
replace exer_weekly = . if m11104 ==.
label var exer_weekly "Sport or exercise at least once/week"

* Social risk-taking
rename pld0043 lend_things
replace lend_things = (lend_things-6)*-1
rename pld0044 lend_money
replace lend_money = (lend_money-6)*-1
label define freq 1 "[1] Never" 2 "[2] Seldom" 3 "[3] Sometimes" 4 "[4] Often" 5 "[5] Very often"
label values lend_things lend_money freq 

********************
*Controls variables*
********************
*Monthly Household income 
rename hghinc hh_inc
replace hh_inc = hh_inc/(y11101/100) //CPI adjusted
label var hh_inc "Monthly Household Net Income (EUR) (CPI adjusted)"
g lhh_inc = log(hh_inc)
label var lhh_inc "log hh_inc"

*Education
g edu_high=.
replace edu_high=1 if pgpsbil>=3&pgpsbil<=4 // includes Fachhochschule, Abitur
replace edu_high=0 if inlist(pgpsbil,1,2,5,6,7,8) // includes Hauptschule, Realschule, other degree, no degree, not gone to school, degree from abroad
label var edu_high "Has high education"

*Parent's education
gen fsedu_dummy=.
replace fsedu_dummy=1 if fsedu>=3 & fsedu<=4 // includes Fachhochschule, Abitur
replace fsedu_dummy=0 if fsedu==1 | fsedu==2 | fsedu==5 | fsedu==6 | fsedu==7 | fsedu==8 | fsedu==9 // includes Hauptschule, Realschule, other degree, no degree, not gone to school, degree from abroad
gen msedu_dummy=.
replace msedu_dummy=1 if msedu>=3 & msedu<=4
replace msedu_dummy=0 if msedu==1 | msedu==2 | msedu==5 | msedu==6 | msedu==7 | fsedu==8 | fsedu==9
gen paredu=0
replace paredu=. if fsedu_dummy==. & msedu_dummy==.
replace paredu=1 if fsedu_dummy==1 | msedu_dummy==1 // takes highest education of both parents
label variable paredu "father or mother with high education"
drop fsedu_dummy msedu_dummy

*Age
rename d11101 age
g age2 = age^2
label var age2 "Age squared"

*Gender
g male = 1 if sex==1
replace male = 0 if sex==2
label var male "Male"

*Household type
qui tab hgtyp1hh, g(hh_type)
label var hh_type1 "Single person household"
label var hh_type2 "Couple without children"
label var hh_type3 "Single parent"
label var hh_type4 "Couple with children <16"
label var hh_type5 "Couple with children >16"
label var hh_type6 "Couple with children <16 & >16"
label var hh_type7 "Multi-generation household"
label var hh_type8 "Other combination household"

*Heritage
replace germborn = 0 if germborn ==2

*Cognition
rename f96t90g cog_animals
rename f99z90r cog_num_entries
rename f25r cog_corr_words

*Time preference/patience
rename plh0253 patience //0-10 scale
rename plh0254 impulse //0-10 scale
rename plh0244 pess_future //pessimism for future [1-4 scale]
rename plh0183 lsat_5yrs //satisfaction with life 5 years from now [0-10 scale]
rename plh0188 confident_future //confident about the future [1-4 scale]
replace confident_future = (confident_future-5)*-1 //rescale order
label define agree3 1 "[1] Does not apply" 2 "[2] Applies slightly less" 3 "[3] Probably applies" 4 "[4] Applies completely"
label values confident_future agree3

*Life satisfaction
rename plh0182 lsat

*Trust
rename plh0192 trust_pp1 //On the whole trust people (2008, 2013)
replace trust_pp1 = (trust_pp1-5)*-1
label define agree 1 "[1] Disagree Completely" 2 "[2] Disagree" 3 "[3] Agree Slightly" 4 "[4] Agree Completely"
label values trust_pp1 agree 

*Big Five personality traits
rename plh0212 b5_01
rename plh0213 b5_02
rename plh0214 b5_03
rename plh0215 b5_04
rename plh0216 b5_05
rename plh0217 b5_06
rename plh0218 b5_07
rename plh0219 b5_08
rename plh0220 b5_09
rename plh0221 b5_10
rename plh0222 b5_11
rename plh0223 b5_12
rename plh0224 b5_13
rename plh0225 b5_14
rename plh0226 b5_15

foreach var of varlist b5_* {
 replace `var'=. if `var'<0
}
recode b5_07 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rb5_07)
recode b5_12 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rb5_12)
recode b5_03 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rb5_03)
recode b5_05 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rb5_05)
recode b5_10 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rb5_10)
gen b5_O=(b5_04 + b5_09 + b5_14)/3
gen b5_C=(b5_01 + b5_11 + rb5_07)/3
gen b5_E=(b5_02 + b5_08 + rb5_12)/3
gen b5_A=(rb5_03 + b5_06 + b5_13)/3
gen b5_ES=(rb5_05 + rb5_10 + b5_15)/3

*Locas of control
rename plh0245 loc_01
rename plh0128 loc_02
rename plh0246 loc_03
rename plh0005 loc_04
rename plh0247 loc_05
rename plh0248 loc_06
rename plh0249 loc_07
rename plh0250 loc_08
rename plh0251 loc_09
rename plh0252 loc_10
 
order loc_01 loc_02 loc_03 loc_04 loc_05 loc_06 loc_07 loc_08 loc_09 loc_10
 
foreach var of varlist loc_01-loc_10 {
replace `var'=. if `var'<0
}
 
recode loc_02 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rloc_02)
recode loc_03 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rloc_03)
recode loc_05 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rloc_05)
recode loc_07 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rloc_07)
recode loc_08 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rloc_08)
recode loc_10 (1=7) (2=6) (3=5) (5=3) (6=2) (7=1), gen(rloc_10)
gen iloc=(loc_01+rloc_02+rloc_03+rloc_05+rloc_07+rloc_08+rloc_10)/7

*Year dummies
forvalues x=2002/2016 {
	g y_`x' = syear ==`x'
}

***********************************************************************************************
* Save Dataset for Analysis
***********************************************************************************************
save "${project}cleandata.dta", replace
