/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

											MEDIATION ANALYSIS
*****************************************************************************************************************************************

This code provides the summary statistics for the mediators and conducts the mediation analysis including its robustness tests.
It requires the dataset "cleandata.dta" generated by data.do to be stored in the project folder.
Logfile with results will be stored in project folder.
***/

***PLEASE ADJUST PATHS***
global project ...\										//Path where project data is saved

set more off
capture ssc install khb									//can delete if already installed
capture ssc install estout  							//can delete if already installed

***********************************************************************************************
* Load data
***********************************************************************************************

use "${project}cleandata.dta", clear
estimates clear

global controls male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn


*Recoding to make everything in the direction of more risk taking
rename confident_future con_f
recode exer_weekly (1=0) (0=1)
rename exer_weekly no_exer_weekly
label var no_exer_weekly "No sport or exercise at least once a week"
recode healthy_diet (1=4) (2=3) (3=2) (4=1)
rename healthy_diet bad_diet
label var bad_diet "Follows unhealthy diet"
recode supp_h_ins (1=0) (0=1)
rename supp_h_ins no_supphins
label var no_supphins "No additional private insurance"
bys syear: su r_gen patience impulse con_f iloc b5_C b5_ES lsat_5yrs pess_future trust_pp1 cog_*

*Additional variables and cleaning
sort pid syear

foreach var of varlist cog_animals cog_corr_words cog_num_entries {
egen `var'std=std(`var')
}
egen cognition=rowmean(cog_animalsstd cog_corr_wordsstd cog_num_entriesstd)

bys pid: gen inaccuracy=abs(lsat[_n+5]-lsat_5yrs)
gen accuracy=-inaccuracy
gen nonimpulse=-impulse

bys pid: egen perminc=mean(hh_inc)
replace perminc=ln(perminc)

foreach var of varlist patience nonimpulse b5_C b5_ES con_f lsat_5yrs iloc trust_pp1 accuracy cognition {
forvalues i=2002/2016 {
bys pid: replace `var'=`var'[_n-1] if syear==`i' & `var'==.
}
}

g miss_control = 0
foreach var of varlist perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 { //cognition {
	replace miss_control = 1 if `var' ==.
}
drop if miss_control==1
drop if mcs==.

log using ${project}mediationresults, replace

***********************************************************************************************
* Summary statistics of mediators
***********************************************************************************************
*Conditional on control variables
gen mcs_dummy_org=mcs_dummy
set more off
matrix A=(.,.,.,.,.)
foreach var of varlist perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition  {
egen `var'std=std(`var')
reg `var'std mcs_dummy ${controls}, cl(pid)
mat diff_table=r(table)
mat diff=diff_table[1,1]
mat t=diff_table[3,1]
mat p=diff_table[4,1]
reg `var'std mcs_dummy ${controls}, cl(pid)
replace mcs_dummy = 0
margins, grand post
mat mar1=e(b)
mat mu1=mar1[1,1]
replace mcs_dummy=mcs_dummy_org
reg `var'std mcs_dummy ${controls}, cl(pid)
replace mcs_dummy = 1
margins, grand post
mat mar2=e(b)
mat mu2=mar2[1,1]
replace mcs_dummy=mcs_dummy_org
mat B=mu1,mu2,diff,t,p
mat A=A\B
mat drop B diff_table mar1 mar2 mu1 mu2 diff t p
}
mat A=A[2...,1...]
mat colnames A= mean_mcs0 mean_mcs1 diff tstat pval
mat rownames A= perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition 
mat list A, f(%9.3f)
mat drop A
drop mcs_dummy_org

*Unconditional 
set more off
matrix A=(.,.,.,.,.,.)
foreach var of varlist perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition  {
ttest `var'std, by(mcs_dummy)
mat B=r(mu_1),r(mu_2),r(t),r(p),r(N_1),r(N_2)
mat A=A\B
mat drop B
}
mat A=A[2...,1...]
mat colnames A= mean_mcs0 mean_mcs1 tstat pval obs_mcs0 obs_mcs1
mat rownames A= perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition 
mat list A, f(%9.3f)
mat drop A


***********************************************************************************************
* Main mediation analysis
***********************************************************************************************

*Probit: Finance, Health
mat A=(.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.)
quietly foreach var of varlist risky_assets no_supphins smoke_curr no_exer_weekly {
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape vce(cluster pid)
mat B1=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\.\.\.\.\.\.\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Health
quietly foreach var of varlist bad_diet {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Social
quietly foreach var of varlist lend_things lend_money {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#5) vce(cluster pid)
mat B5=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\B5[1,1]\B5[1,2]\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

mat A=A[1...,2...]
mat rownames A= Coef_r Coef_f APE1_r APE1_f APE2_r APE2_f APE3_r APE3_f APE4_r APE4_f APE5_r APE5_f perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 percent obs
mat list A, f(%9.3f)

* Only to obtain number of persons
quietly foreach var of varlist risky_assets no_supphins smoke_curr bad_diet no_exer_weekly lend_things lend_money {
reg `var' mcs_dummy perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn, cluster(pid)
estimates store `var', title(`var')
}
estout risky_assets no_supphins smoke_curr bad_diet no_exer_weekly lend_things lend_money, stats(N N_clust, fmt(0 0))
estimates clear

***********************************************************************************************
* Robustness checks of mediation analysis
***********************************************************************************************

************************************************
*Robustness check: drop log income from controls
************************************************
estimates clear
mat drop A
set more off

preserve
drop if lhh_inc==.

*Probit: Finance, Health
mat A=(.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.)
quietly foreach var of varlist risky_assets no_supphins smoke_curr no_exer_weekly {
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape vce(cluster pid)
mat B1=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\.\.\.\.\.\.\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Health
quietly foreach var of varlist bad_diet {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Social
quietly foreach var of varlist lend_things lend_money {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 , d s c(male age age2 edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#5) vce(cluster pid)
mat B5=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\B5[1,1]\B5[1,2]\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

mat A=A[1...,2...]
mat rownames A= Coef_r Coef_f APE1_r APE1_f APE2_r APE2_f APE3_r APE3_f APE4_r APE4_f APE5_r APE5_f perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 percent obs
mat list A, f(%9.3f)

restore

****************************************
*Robustness check: include risk aversion
****************************************
estimates clear
preserve
mat drop A
set more off
drop if r_gen==.

*Probit: Finance, Health
mat A=(.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.)
quietly foreach var of varlist risky_assets no_supphins smoke_curr no_exer_weekly {
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape vce(cluster pid)
mat B1=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\.\.\.\.\.\.\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Health
quietly foreach var of varlist bad_diet {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Social
quietly foreach var of varlist lend_things lend_money {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#5) vce(cluster pid)
mat B5=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\B5[1,1]\B5[1,2]\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

mat A=A[1...,2...]
mat rownames A= Coef_r Coef_f APE1_r APE1_f APE2_r APE2_f APE3_r APE3_f APE4_r APE4_f APE5_r APE5_f perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 r_gen percent obs
mat list A, f(%9.3f)
restore

*******************************************
*Robustness check: include cognitive skills
*******************************************
estimates clear
preserve
mat drop A
set more off
drop if cognition==.

*Probit: Finance, Health
mat A=(.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.\.)
quietly foreach var of varlist risky_assets no_supphins smoke_curr no_exer_weekly {
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb probit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape vce(cluster pid)
mat B1=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\.\.\.\.\.\.\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Health
quietly foreach var of varlist bad_diet {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\.\.\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

*Oprobit: Social
quietly foreach var of varlist lend_things lend_money {
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) vce(cluster pid)
mat B=e(b)
mat C=e(pct_mcs_dummy)
mat D=e(disentangle)
mat E=e(N)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#1) vce(cluster pid)
mat B1=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#2) vce(cluster pid)
mat B2=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#3) vce(cluster pid)
mat B3=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#4) vce(cluster pid)
mat B4=e(b)
ereturn clear
eststo: khb oprobit `var' mcs_dummy || perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition, d s c(male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn) ape outcome(#5) vce(cluster pid)
mat B5=e(b)
mat F=(B[1,1]\B[1,2]\B1[1,1]\B1[1,2]\B2[1,1]\B2[1,2]\B3[1,1]\B3[1,2]\B4[1,1]\B4[1,2]\B5[1,1]\B5[1,2]\D[1...,4]\C\E)
mat colnames F=`var'
mat A=A,F
mat drop B C D E F
ereturn clear
	}
esttab, se compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3)
estimates clear

mat A=A[1...,2...]
mat rownames A= Coef_r Coef_f APE1_r APE1_f APE2_r APE2_f APE3_r APE3_f APE4_r APE4_f APE5_r APE5_f perminc patience nonimpulse b5_C iloc b5_ES con_f accuracy trust_pp1 cognition percent obs
mat list A, f(%9.3f)
restore
log close
