/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

											ESTIMATION RISK-TAKING BEHAVIORS
*****************************************************************************************************************************************

This code computes the correlation between the MCS depression indicator and self-reported diagnosed depression.
It requires the dataset "cleandata.dta" generated by data.do to be stored in the project folder and the original SOEP data in long format.
***/

***PLEASE ADJUST PATHS***
global project ...\										//Path where project data is saved

capture ssc install estout  //can delete if already installed

use "${project}cleandata.dta", clear

//================================================================
//Recoding to make everything in the direction of more risk taking
//================================================================

recode exer_weekly (1=0) (0=1)
rename exer_weekly no_exer_weekly
label var no_exer_weekly "No sport or exercise at least once a week"
recode healthy_diet (1=4) (2=3) (3=2) (4=1)
rename healthy_diet bad_diet
label var bad_diet "Follows unhealthy diet"
recode supp_h_ins (1=0) (0=1)
rename supp_h_ins no_supp_h_ins
label var no_supp_h_ins "Does not have supplmentary health insurance"

//===================
//Macros and cleaning
//===================

g miss_control = 0
local controls male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn y_*

foreach var of varlist `controls' {
	replace miss_control = 1 if `var' ==.
}

mark cond if miss_control==0

//================
//Main Eestimation
//================

if 1==1 {
*Finance
foreach var in risky_assets no_supp_h_ins {
	eststo: qui probit `var' i.mcs_dummy if cond, cl(pid)
	margins, dydx(1.mcs_dummy)
	tab `var' if e(sample)
	eststo: qui probit `var' i.mcs_dummy `controls' if cond, cl(pid)
	margins, dydx(1.mcs_dummy)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

*Health
foreach var in smoke_curr no_exer_weekly {
	eststo: qui probit `var' i.mcs_dummy if cond, cl(pid)
	margins, dydx(1.mcs_dummy)
	tab `var' if e(sample)
	eststo: qui probit `var' i.mcs_dummy `controls' if cond, cl(pid)
	margins, dydx(1.mcs_dummy)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

eststo: qui oprobit bad_diet i.mcs_dummy if cond, cl(pid)
margins, dydx(1.mcs_dummy)
tab bad_diet if e(sample)
eststo: qui oprobit bad_diet i.mcs_dummy `controls' if cond, cl(pid)
margins, dydx(1.mcs_dummy)
esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
eststo clear

*Social
foreach var in lend_things lend_money {
	eststo: qui oprobit `var' i.mcs_dummy if cond, cl(pid)
	margins, dydx(1.mcs_dummy)
	tab `var' if e(sample)
	eststo: qui oprobit `var' i.mcs_dummy `controls' if cond, cl(pid)
	margins, dydx(1.mcs_dummy)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}
}

//=================================================
//Estimation controlling for stated risk preference
//=================================================

if 1==1 {
*Finance
foreach var in risky_assets no_supp_h_ins {	
	eststo: qui probit `var' i.mcs_dummy `controls' r_gen if cond, cl(pid)
	tab `var' if e(sample)
	margins, dydx(1.mcs_dummy)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

*Health
foreach var in smoke_curr no_exer_weekly {
	eststo: qui probit `var' i.mcs_dummy `controls' r_gen if cond, cl(pid)
	tab `var' if e(sample)
	margins, dydx(1.mcs_dummy)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

eststo: qui oprobit bad_diet i.mcs_dummy `controls' r_gen if cond, cl(pid)
tab bad_diet if e(sample)
margins, dydx(1.mcs_dummy)
esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.001) b(3) scalar(N_clust r2_p)
eststo clear

*Social
foreach var in lend_things lend_money {	
	eststo: qui oprobit `var' i.mcs_dummy `controls' r_gen if cond, cl(pid)
	tab `var' if e(sample)
	margins, dydx(1.mcs_dummy)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}
}

//===========================================
//Estimation using MCS score instead of dummy
//===========================================

if 1==1 {
*Finance
foreach var in risky_assets no_supp_h_ins {
	eststo: qui probit `var' mcs if cond, cl(pid)
	margins, dydx(mcs)
	tab `var' if e(sample)
	eststo: qui probit `var' mcs `controls' if cond, cl(pid)
	margins, dydx(mcs)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

*Health
foreach var in smoke_curr no_exer_weekly {
	eststo: qui probit `var' mcs if cond, cl(pid)
	margins, dydx(mcs)
	tab `var' if e(sample)
	eststo: qui probit `var' mcs `controls' if cond, cl(pid)
	margins, dydx(mcs)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

eststo: qui oprobit bad_diet mcs if cond, cl(pid)
margins, dydx(mcs)
tab bad_diet if e(sample)
eststo: qui oprobit bad_diet mcs `controls' if cond, cl(pid)
margins, dydx(mcs)
esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
eststo clear

*Social
foreach var in lend_things lend_money {
	eststo: qui oprobit `var' mcs if cond, cl(pid)
	margins, dydx(mcs)
	tab `var' if e(sample)
	eststo: qui oprobit `var' mcs `controls' if cond, cl(pid)
	margins, dydx(mcs)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}
}

//========================================
//Estimation using alternate MCS threshold
//========================================

if 1==1 {
*Create dummy
gen mcs_dummy2=.
replace mcs_dummy2=1 if mcs<=36.54 & mcs!=.
replace mcs_dummy2=0 if mcs>36.54 & mcs!=.
label var mcs_dummy2 "MCS <=36.54"

*Finance
foreach var in risky_assets no_supp_h_ins {
	eststo: qui probit `var' i.mcs_dummy2 if cond, cl(pid)
	margins, dydx(1.mcs_dummy2)
	tab `var' if e(sample)
	eststo: qui probit `var' i.mcs_dummy2 `controls' if cond, cl(pid)
	margins, dydx(1.mcs_dummy2)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

*Health
foreach var in smoke_curr no_exer_weekly {
	eststo: qui probit `var' i.mcs_dummy2 if cond, cl(pid)
	margins, dydx(1.mcs_dummy2)
	tab `var' if e(sample)
	eststo: qui probit `var' i.mcs_dummy2 `controls' if cond, cl(pid)
	margins, dydx(1.mcs_dummy2)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}

eststo: qui oprobit bad_diet i.mcs_dummy2 if cond, cl(pid)
margins, dydx(1.mcs_dummy2)
tab bad_diet if e(sample)
eststo: qui oprobit bad_diet i.mcs_dummy2 `controls' if cond, cl(pid)
margins, dydx(1.mcs_dummy2)
esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
eststo clear

*Social
foreach var in lend_things lend_money {
	eststo: qui oprobit `var' i.mcs_dummy2 if cond, cl(pid)
	margins, dydx(1.mcs_dummy2)
	tab `var' if e(sample)
	eststo: qui oprobit `var' i.mcs_dummy2 `controls' if cond, cl(pid)
	margins, dydx(1.mcs_dummy2)
	esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_clust r2_p)
	eststo clear
}
}
