/***
*****************************************************************************************************************************************
Depression, Risk Preferences and Risk-taking Behavior
Cobb-Clark, Dahmann, Kettlewell

													REGRESSIONS ON STATED RISK PREFERENCES
*****************************************************************************************************************************************

This code estimatesthe various regression models on the stated risk preference variables in each domain. 
It requires the dataset "cleandata.dta" generated by data.do to be stored in the project folder and the original SOEP data in long format.
***/

***PLEASE ADJUST PATHS***
global project ...\		

capture ssc install estout  //can delete if already installed

use "${project}cleandata.dta", clear

local controls male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn y_*

g miss_control = 0
foreach var in male age age2 lhh_inc edu_high paredu hh_type1 hh_type2 hh_type3 hh_type4 hh_type5 hh_type6 hh_type7 germborn mcs_dummy {
	replace miss_control = 1 if `var' ==.
}

//======================
//Pooled OLS no controls
//======================

foreach var in gen drive fin sport occup health trust {
	eststo: qui reg r_`var' mcs_dummy if miss_control==0, cl(pid)
	scalar beta = _b[mcs_dummy]
	qui sum r_`var' if mcs_dummy==1
	scalar g_`var' = beta/r(sd) //Hedge's g
	qui sum r_`var'
	scalar p_`var' = beta/r(mean) //percentage change
}

esttab using ".\table_SP_1", se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) title("Pooled OLS regression results") rtf replace
eststo clear

*Fill matrix with effect sizes
matrix EFF1 = J(2,7,0)
matrix EFF1[1,1] = g_gen
matrix EFF1[1,2] = g_drive
matrix EFF1[1,3] = g_fin
matrix EFF1[1,4] = g_sport
matrix EFF1[1,5] = g_occup
matrix EFF1[1,6] = g_health
matrix EFF1[1,7] = g_trust

matrix EFF1[2,1] = p_gen
matrix EFF1[2,2] = p_drive
matrix EFF1[2,3] = p_fin
matrix EFF1[2,4] = p_sport
matrix EFF1[2,5] = p_occup
matrix EFF1[2,6] = p_health
matrix EFF1[2,7] = p_trust

matrix colnames EFF1 = gen drive fin sport occup health trust
matrix rowname EFF1 = g per
matrix list EFF1

//========================
//Pooled OLS with controls
//========================

foreach var in gen drive fin sport occup health trust {
	eststo: qui reg r_`var' mcs_dummy `controls', cl(pid)
	scalar beta = _b[mcs_dummy]
	qui sum r_`var' if mcs_dummy==1
	scalar g_`var' = beta/r(sd) //Hedge's g
	qui sum r_`var'
	scalar p_`var' = beta/r(mean) //percentage change
}

esttab using ".\table_SP_2", se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) title("Pooled OLS regression results") rtf replace
eststo clear

*Fill matrix with effect sizes
matrix EFF2 = J(2,7,0)
matrix EFF2[1,1] = g_gen
matrix EFF2[1,2] = g_drive
matrix EFF2[1,3] = g_fin
matrix EFF2[1,4] = g_sport
matrix EFF2[1,5] = g_occup
matrix EFF2[1,6] = g_health
matrix EFF2[1,7] = g_trust

matrix EFF2[2,1] = p_gen
matrix EFF2[2,2] = p_drive
matrix EFF2[2,3] = p_fin
matrix EFF2[2,4] = p_sport
matrix EFF2[2,5] = p_occup
matrix EFF2[2,6] = p_health
matrix EFF2[2,7] = p_trust

matrix colnames EFF2 = gen drive fin sport occup health trust
matrix rowname EFF2 = g per
matrix list EFF2

//=============
//Fixed effects
//=============

foreach var in gen drive fin sport occup health trust {
	eststo: qui xtreg r_`var' mcs_dummy `controls', fe cl(pid)
	scalar beta = _b[mcs_dummy]
	qui sum r_`var' if mcs_dummy==1
	scalar g_`var' = beta/r(sd) //Hedge's g
	qui sum r_`var'
	scalar p_`var' = beta/r(mean) //percentage change
}

esttab using ".\table_SP_3", se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_g r2_o rho) ///
title("FE OLS regression results") replace rtf
eststo clear

*Fill matrix with effect sizes
matrix EFF3 = J(2,7,0)
matrix EFF3[1,1] = g_gen
matrix EFF3[1,2] = g_drive
matrix EFF3[1,3] = g_fin
matrix EFF3[1,4] = g_sport
matrix EFF3[1,5] = g_occup
matrix EFF3[1,6] = g_health
matrix EFF3[1,7] = g_trust

matrix EFF3[2,1] = p_gen
matrix EFF3[2,2] = p_drive
matrix EFF3[2,3] = p_fin
matrix EFF3[2,4] = p_sport
matrix EFF3[2,5] = p_occup
matrix EFF3[2,6] = p_health
matrix EFF3[2,7] = p_trust

matrix colnames EFF3 = gen drive fin sport occup health trust
matrix rowname EFF3 = g per
matrix list EFF3

//============================================
//Sensitivity: use MCS score rather than dummy
//============================================

local controls male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn y_*

foreach var in gen drive fin sport occup health trust {
	eststo: qui reg r_`var' mcs if miss_control==0, cl(pid)
}

esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) title("Pooled OLS regression results")
eststo clear

foreach var in gen drive fin sport occup health trust {
	eststo: qui reg r_`var' mcs `controls', cl(pid)
}

esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) title("Pooled OLS regression results")
eststo clear

foreach var in gen drive fin sport occup health trust {
	eststo: qui xtreg r_`var' mcs `controls', fe cl(pid)
}

esttab using ".\table_SP_4", se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_g r2_o rho) ///
title("OLS regression results")
eststo clear

//========================================
//Sensitivity: use alternate MCS threshold
//========================================

gen mcs_dummy2=.
replace mcs_dummy2=1 if mcs<=36.54 & mcs!=.
replace mcs_dummy2=0 if mcs>36.54 & mcs!=.
label var mcs_dummy2 "MCS <=36.54"

local controls male age age2 lhh_inc edu_high paredu hh_type1-hh_type7 germborn y_*

foreach var in gen drive fin sport occup health trust {
	eststo: qui reg r_`var' mcs_dummy2 if miss_control==0, cl(pid)
}

esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) title("Pooled OLS regression results")
eststo clear

foreach var in gen drive fin sport occup health trust {
	eststo: qui reg r_`var' mcs_dummy2 `controls', cl(pid)
}

esttab, se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) title("Pooled OLS regression results")
eststo clear

foreach var in gen drive fin sport occup health trust {
	eststo: qui xtreg r_`var' mcs_dummy2 `controls', fe cl(pid)
}

esttab using ".\table_SP_5", se r2 compress starlevels(* 0.1 ** 0.05 *** 0.01) b(3) scalar(N_g r2_o rho) ///
title("Alternate MCS OLS regression results")
eststo clear
